@@ -1,7 +1,7 @@
 \unset ECHO
 \i test/setup.sql
 
-SELECT plan(84);
+SELECT plan(90);
 --SELECT * FROM no_plan();
 
 -- This will be rolled back. :-)
@@ -139,6 +139,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    col_is_pk( 'public', 'sometab', 'id'::name ),
+    true,
+    'col_is_pk( schema, table, column )',
+    'Column public.sometab(id) should be a primary key',
+    ''
+);
+
 SELECT * FROM check_test(
     col_is_pk( 'sometab', 'id', 'sometab.id should be a pk' ),
     true,
@@ -192,6 +200,14 @@ SELECT * FROM check_test(
     ''
 );
 
+SELECT * FROM check_test(
+    col_is_pk( 'public', 'argh', ARRAY['id', 'name']::name[] ),
+    true,
+    'col_is_pk( schema, table, column[] )',
+    'Columns public.argh(id, name) should be a primary key',
+    ''
+);
+
 SELECT * FROM check_test(
     col_is_pk( 'argh', ARRAY['id', 'name'], 'id + name should be a pk' ),
     true,
